import { Configuration } from '../node_modules/mathjax-full/js/input/tex/Configuration.js'
import { CommandMap } from '../node_modules/mathjax-full/js/input/tex/SymbolMap.js'
import TexError from '../node_modules/mathjax-full/js/input/tex/TexError.js'

const getDecmarkerToken = (parser) =>
  parser.create(
    'token',
    'mo',
    {},
    (1.1).toLocaleString(document.documentElement.lang).substring(1, 2)
  )

const numMethods = {
  decmarkerMethod: (parser) => {
    parser.Push(getDecmarkerToken(parser))
  },
  numMethod: (parser, name) => {
    const arg = parser.GetArgument(name)
    const match = arg.match(/^(\d+)[,.](\d*)$/)
    if (!match) {
      throw new TexError(
        'BadArgument',
        'Could not parse argument in %1: %2',
        name,
        arg
      )
    }
    parser.Push(parser.create('node', 'mn', [parser.create('text', match[1])]))
    parser.Push(parser.create('node', 'TeXAtom', [getDecmarkerToken(parser)]))
    parser.Push(parser.create('node', 'mn', [parser.create('text', match[2])]))
  },
}

new CommandMap(
  'numMap',
  {
    num: 'numMethod',
    decmarker: 'decmarkerMethod',
  },
  numMethods
)

Configuration.create('num', {
  handler: { macro: ['numMap'] },
})
